@@ -26,7 +26,7 @@ except ImportError:
 import firmware_addon_dell as fad
 import extract_common as common
 import biosHdr
-from extract_bios_blacklist import dell_system_id_blacklist
+from extract_bios_blacklist import dell_system_id_blacklist, dell_system_specific_bios_blacklist 
 
 # required by the Firmware-Tools plugin API
 __VERSION__ = firmwaretools.__VERSION__
@@ -189,7 +189,7 @@ def setupWine():
         "HOME":os.environ["HOME"],
         "WINEPREFIX": wineprefix,
         }
-    common.loggedCmd(["wineprefixcreate", "-w", "--prefix", wineprefix], cwd=wineprefix, env=env, logger=getLog())
+    common.loggedCmd(["wineprefixcreate", "-w", "--prefix", wineprefix], cwd=wineprefix, env=env, logger=getLog(), raiseExc=False)
     atexit.register(shutil.rmtree, wineprefix)
     getLog(prefix="verbose.").info("Wine pre-setup finished.")
 
@@ -248,7 +248,7 @@ def biosFromLinuxDup2(statusObj, outputTopdir, logger, *args, **kargs):
     except (OSError, common.CommandException), e:
         raise common.skip, str(e)
 
-    for hdr, id, ver in getHdrIdVer(statusObj.tmpdir):
+    for hdr, id, ver in getHdrIdVer(statusObj.tmpdir, os.path.join(statusObj.tmpdir, "Package")):
         dest, packageIni = copyHdr(hdr, id, ver, outputTopdir, logger)
         for txt in glob.glob( "%s.[Tt][Xx][Tt]" % statusObj.file[:-len(".txt")] ):
             shutil.copyfile( txt, os.path.join(dest, "relnotes.txt") )
@@ -280,7 +280,7 @@ def biosFromLinuxDup3(statusObj, outputTopdir, logger, *args, **kargs):
     except (OSError, common.CommandException), e:
         raise common.skip, str(e)
 
-    for hdr, id, ver in getHdrIdVer(statusObj.tmpdir):
+    for hdr, id, ver in getHdrIdVer(statusObj.tmpdir, os.path.join(statusObj.tmpdir, "Package")):
         dest, packageIni = copyHdr(hdr, id, ver, outputTopdir, logger)
         for txt in glob.glob( "%s.[Tt][Xx][Tt]" % statusObj.file[:-len(".txt")] ):
             shutil.copyfile( txt, os.path.join(dest, "relnotes.txt") )
@@ -316,7 +316,7 @@ def genericBiosDup(statusObj, outputTopdir, logger, *args, **kargs):
         deps[sysId] = reqver
 
     gotOne=False
-    for hdr, id, ver in getHdrIdVer(statusObj.tmpdir):
+    for hdr, id, ver in getHdrIdVer(statusObj.tmpdir, os.path.join(statusObj.tmpdir, "Package")):
         gotOne=True
         dest, packageIni = copyHdr(hdr, id, ver, outputTopdir, logger)
         if os.path.exists(os.path.join(dest, "package.xml")):
@@ -383,7 +383,7 @@ def biosFromWindowsExe(statusObj, outputTopdir, logger, *args, **kargs):
     except OSError, e:
         raise common.skip, "wine not installed"
 
-    for hdr, id, ver in getHdrIdVer(statusObj.tmpdir):
+    for hdr, id, ver in getHdrIdVer(statusObj.tmpdir, os.path.join(statusObj.tmpdir, "Package")):
         dest, packageIni = copyHdr(hdr, id, ver, outputTopdir, logger)
         for txt in glob.glob( "%s.[Tt][Xx][Tt]" % statusObj.file[:-len(".txt")] ):
             shutil.copyfile( txt, os.path.join(dest, "relnotes.txt") )
@@ -546,7 +546,14 @@ def copyHdr(hdr, id, ver, destTop, logger):
         shortname = shortName.getShortname("0x1028", "0x%04x" % id),
     )
 
+    blacklisted = 0
     if id in dell_system_id_blacklist:
+        blacklisted = 1
+
+    if (id, ver.lower()) in dell_system_specific_bios_blacklist:
+        blacklisted = 1
+
+    if blacklisted:
         common.setIni( packageIni, "package",
             blacklisted="1",
             blacklist_reason="Broken RBU implementation.",
